==> paraview-5.8.1-3-x86_64.pkg.tar.zst: usr/lib/python3.9/site-packages/vtkmodules/all.py <==
""" This module loads the entire VTK library into its namespace.  It
also allows one to use specific packages inside the vtk directory.."""

from __future__ import absolute_import

# --------------------------------------
from .vtkCommonCore import *
from .vtkWebCore import *
from .vtkCommonMath import *
from .vtkCommonTransforms import *
from .vtkCommonDataModel import *
from .vtkCommonExecutionModel import *
from .vtkIOCore import *
from .vtkIOImage import *
from .vtkIOXMLParser import *
from .vtkIOXML import *
from .vtkCommonMisc import *
from .vtkFiltersCore import *
from .vtkRenderingCore import *
from .vtkRenderingContext2D import *
from .vtkRenderingFreeType import *
from .vtkIOExport import *
from .vtkWebGLExporter import *
from .vtkFiltersGeneral import *
from .vtkFiltersSources import *
from .vtkInteractionWidgets import *
from .vtkViewsCore import *
from .vtkViewsContext2D import *
from .vtkTestingRendering import *
from .vtkRenderingOpenGL2 import *
from .vtkRenderingSceneGraph import *
from .vtkRenderingVolume import *
from .vtkRenderingRayTracing import *
from .vtkImagingCore import *
from .vtkImagingMath import *
from .vtkRenderingVolumeOpenGL2 import *
from .vtkRenderingVolumeAMR import *
from .vtkRenderingParallel import *
from .vtkRenderingMatplotlib import *
from .vtkRenderingLabel import *
from .vtkRenderingLICOpenGL2 import *
from .vtkRenderingContextOpenGL2 import *
from .vtkParallelMPI4Py import *
from .vtkIOLegacy import *
from .vtkIOXdmf2 import *
from .vtkIOVeraOut import *
from .vtkIOVPIC import *
from .vtkIOTecplotTable import *
from .vtkIOTRUCHAS import *
from .vtkIOSegY import *
from .vtkIOXdmf3 import *
from .vtkIOParallelXML import *
from .vtkIONetCDF import *
from .vtkIOParallelNetCDF import *
from .vtkIOLSDyna import *
from .vtkIOParallelLSDyna import *
from .vtkIOExodus import *
from .vtkIOParallelExodus import *
from .vtkIOPLY import *
from .vtkIOPIO import *
from .vtkIOPDAL import *
from .vtkIOMovie import *
from .vtkIOOggTheora import *
from .vtkIOMotionFX import *
from .vtkIOGeometry import *
from .vtkIOParallel import *
from .vtkIOMPIImage import *
from .vtkIOInfovis import *
from .vtkCommonColor import *
from .vtkImagingSources import *
from .vtkInfovisCore import *
from .vtkIOImport import *
from .vtkIOH5part import *
from .vtkIOVideo import *
from .vtkIOFFMPEG import *
from .vtkRenderingGL2PSOpenGL2 import *
from .vtkIOExportGL2PS import *
from .vtkIOEnSight import *
from .vtkIOCityGML import *
from .vtkIOAsynchronous import *
from .vtkIOAMR import *
from .vtkIOGDAL import *
from .vtkImagingColor import *
from .vtkRenderingAnnotation import *
from .vtkInteractionStyle import *
from .vtkImagingHybrid import *
from .vtkFiltersPython import *
from .vtkFiltersProgrammable import *
from .vtkFiltersModeling import *
from .vtkFiltersPoints import *
from .vtkFiltersVerdict import *
from .vtkParallelCore import *
from .vtkFiltersParallelVerdict import *
from .vtkFiltersStatistics import *
from .vtkFiltersParallelStatistics import *
from .vtkCommonSystem import *
from .vtkFiltersGeometry import *
from .vtkFiltersExtraction import *
from .vtkFiltersTexture import *
from .vtkFiltersParallel import *
from .vtkParallelMPI import *
from .vtkFiltersParallelGeometry import *
from .vtkCommonComputationalGeometry import *
from .vtkFiltersFlowPaths import *
from .vtkFiltersParallelFlowPaths import *
from .vtkFiltersParallelDIY2 import *
from .vtkImagingGeneral import *
from .vtkFiltersHyperTree import *
from .vtkFiltersHybrid import *
from .vtkFiltersGeneric import *
from .vtkFiltersAMR import *
from .vtkFiltersParallelMPI import *
from .vtkDomainsChemistry import *
from .vtkDomainsChemistryOpenGL2 import *
from .vtkChartsCore import *
from .vtkImagingFourier import *
from .vtkAcceleratorsVTKm import *


# useful macro for getting type names
from .util.vtkConstants import vtkImageScalarTypeNameMacro

# import convenience decorators
from .util.misc import calldata_type

# import the vtkVariant helpers
from .util.vtkVariant import *

==> paraview-5.9.1-5-x86_64.pkg.tar.zst: usr/lib/python3.9/site-packages/vtkmodules/all.py <==
""" This module loads the entire VTK library into its namespace.  It
also allows one to use specific packages inside the vtk directory.."""

from __future__ import absolute_import

# --------------------------------------
from .vtkCommonCore import *
from .vtkWebCore import *
from .vtkCommonMath import *
from .vtkCommonTransforms import *
from .vtkCommonDataModel import *
from .vtkCommonExecutionModel import *
from .vtkIOCore import *
from .vtkImagingCore import *
from .vtkIOImage import *
from .vtkIOXMLParser import *
from .vtkIOXML import *
from .vtkCommonMisc import *
from .vtkFiltersCore import *
from .vtkRenderingCore import *
from .vtkRenderingContext2D import *
from .vtkRenderingFreeType import *
from .vtkRenderingSceneGraph import *
from .vtkRenderingVtkJS import *
from .vtkIOExport import *
from .vtkWebGLExporter import *
from .vtkFiltersGeneral import *
from .vtkFiltersSources import *
from .vtkInteractionWidgets import *
from .vtkViewsCore import *
from .vtkViewsContext2D import *
from .vtkTestingRendering import *
from .vtkIOLegacy import *
from .vtkDomainsChemistry import *
from .vtkRenderingUI import *
from .vtkRenderingOpenGL2 import *
from .vtkRenderingVolume import *
from .vtkRenderingRayTracing import *
from .vtkImagingMath import *
from .vtkRenderingVolumeOpenGL2 import *
from .vtkRenderingVolumeAMR import *
from .vtkRenderingParallel import *
from .vtkRenderingMatplotlib import *
from .vtkRenderingLabel import *
from .vtkRenderingLICOpenGL2 import *
from .vtkRenderingContextOpenGL2 import *
from .vtkParallelMPI4Py import *
from .vtkIOXdmf2 import *
from .vtkIOVeraOut import *
from .vtkIOVPIC import *
from .vtkIOTecplotTable import *
from .vtkIOTRUCHAS import *
from .vtkIOSegY import *
from .vtkIOXdmf3 import *
from .vtkIOParallelXML import *
from .vtkIONetCDF import *
from .vtkIOParallelNetCDF import *
from .vtkIOLSDyna import *
from .vtkIOParallelLSDyna import *
from .vtkIOExodus import *
from .vtkIOParallelExodus import *
from .vtkIOPLY import *
from .vtkIOPIO import *
from .vtkIOPDAL import *
from .vtkIOMovie import *
from .vtkIOOggTheora import *
from .vtkIOMotionFX import *
from .vtkIOGeometry import *
from .vtkIOParallel import *
from .vtkIOMPIImage import *
from .vtkIOLAS import *
from .vtkParallelCore import *
from .vtkIOIoss import *
from .vtkIOInfovis import *
from .vtkCommonColor import *
from .vtkImagingSources import *
from .vtkInfovisCore import *
from .vtkIOImport import *
from .vtkIOH5part import *
from .vtkIOH5Rage import *
from .vtkIOFides import *
from .vtkAcceleratorsVTKmCore import *
from .vtkAcceleratorsVTKmDataModel import *
from .vtkIOVideo import *
from .vtkIOFFMPEG import *
from .vtkRenderingGL2PSOpenGL2 import *
from .vtkIOExportGL2PS import *
from .vtkIOEnSight import *
from .vtkIOCityGML import *
from .vtkIOCONVERGECFD import *
from .vtkIOAsynchronous import *
from .vtkIOAMR import *
from .vtkIOADIOS2 import *
from .vtkIOGDAL import *
from .vtkImagingColor import *
from .vtkRenderingAnnotation import *
from .vtkInteractionStyle import *
from .vtkImagingHybrid import *
from .vtkFiltersPython import *
from .vtkFiltersProgrammable import *
from .vtkFiltersModeling import *
from .vtkFiltersPoints import *
from .vtkFiltersVerdict import *
from .vtkFiltersParallelVerdict import *
from .vtkFiltersStatistics import *
from .vtkFiltersParallelStatistics import *
from .vtkCommonSystem import *
from .vtkFiltersGeometry import *
from .vtkFiltersExtraction import *
from .vtkFiltersHybrid import *
from .vtkFiltersTexture import *
from .vtkFiltersParallel import *
from .vtkParallelMPI import *
from .vtkFiltersParallelGeometry import *
from .vtkCommonComputationalGeometry import *
from .vtkFiltersFlowPaths import *
from .vtkFiltersParallelFlowPaths import *
from .vtkFiltersParallelDIY2 import *
from .vtkImagingGeneral import *
from .vtkFiltersHyperTree import *
from .vtkFiltersGeneric import *
from .vtkFiltersAMR import *
from .vtkFiltersParallelMPI import *
from .vtkDomainsChemistryOpenGL2 import *
from .vtkChartsCore import *
from .vtkImagingFourier import *
from .vtkAcceleratorsVTKmFilters import *


# useful macro for getting type names
from .util.vtkConstants import vtkImageScalarTypeNameMacro

# import convenience decorators
from .util.misc import calldata_type

# import the vtkVariant helpers
from .util.vtkVariant import *
